@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import math
 
@@ -10,7 +8,7 @@ from .core import Kernel1D, Kernel2D, Kernel
 from .utils import KernelSizeError
 from ..modeling import models
 from ..modeling.core import Fittable1DModel, Fittable2DModel
-
+from ..utils.decorators import deprecated_renamed_argument
 
 __all__ = ['Gaussian1DKernel', 'Gaussian2DKernel', 'CustomKernel',
            'Box1DKernel', 'Box2DKernel', 'Tophat2DKernel',
@@ -20,7 +18,7 @@ __all__ = ['Gaussian1DKernel', 'Gaussian2DKernel', 'CustomKernel',
 
 
 def _round_up_to_odd_integer(value):
-    i = int(math.ceil(value))  # TODO: int() call is only needed for six.PY2
+    i = math.ceil(value)
     if i % 2 == 0:
         return i + 1
     else:
@@ -86,7 +84,7 @@ class Gaussian1DKernel(Kernel1D):
         self._model = models.Gaussian1D(1. / (np.sqrt(2 * np.pi) * stddev),
                                         0, stddev)
         self._default_size = _round_up_to_odd_integer(8 * stddev)
-        super(Gaussian1DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = np.abs(1. - self._array.sum())
 
 
@@ -99,8 +97,13 @@ class Gaussian2DKernel(Kernel2D):
 
     Parameters
     ----------
-    stddev : number
-        Standard deviation of the Gaussian kernel.
+    x_stddev : float
+        Standard deviation of the Gaussian in x before rotating by theta.
+    y_stddev : float
+        Standard deviation of the Gaussian in y before rotating by theta.
+    theta : float
+        Rotation angle in radians. The rotation angle increases
+        counterclockwise.
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * stddev.
     y_size : odd int, optional
@@ -148,11 +151,16 @@ class Gaussian2DKernel(Kernel2D):
     _separable = True
     _is_bool = False
 
-    def __init__(self, stddev, **kwargs):
-        self._model = models.Gaussian2D(1. / (2 * np.pi * stddev ** 2), 0,
-                                        0, stddev, stddev)
-        self._default_size = _round_up_to_odd_integer(8 * stddev)
-        super(Gaussian2DKernel, self).__init__(**kwargs)
+    @deprecated_renamed_argument('stddev', 'x_stddev', '3.0')
+    def __init__(self, x_stddev, y_stddev=None, theta=0.0, **kwargs):
+        if y_stddev is None:
+            y_stddev = x_stddev
+        self._model = models.Gaussian2D(1. / (2 * np.pi * x_stddev * y_stddev),
+                                        0, 0, x_stddev=x_stddev,
+                                        y_stddev=y_stddev, theta=theta)
+        self._default_size = _round_up_to_odd_integer(
+            8 * np.max([x_stddev, y_stddev]))
+        super().__init__(**kwargs)
         self._truncation = np.abs(1. - self._array.sum())
 
 
@@ -219,7 +227,7 @@ class Box1DKernel(Kernel1D):
         self._model = models.Box1D(1. / width, 0, width)
         self._default_size = _round_up_to_odd_integer(width)
         kwargs['mode'] = 'linear_interp'
-        super(Box1DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = 0
         self.normalize()
 
@@ -289,7 +297,7 @@ class Box2DKernel(Kernel2D):
         self._model = models.Box2D(1. / width ** 2, 0, 0, width, width)
         self._default_size = _round_up_to_odd_integer(width)
         kwargs['mode'] = 'linear_interp'
-        super(Box2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = 0
         self.normalize()
 
@@ -348,7 +356,7 @@ class Tophat2DKernel(Kernel2D):
     def __init__(self, radius, **kwargs):
         self._model = models.Disk2D(1. / (np.pi * radius ** 2), 0, 0, radius)
         self._default_size = _round_up_to_odd_integer(2 * radius)
-        super(Tophat2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = 0
 
 
@@ -408,7 +416,7 @@ class Ring2DKernel(Kernel2D):
         self._model = models.Ring2D(1. / (np.pi * (radius_out ** 2 - radius_in ** 2)),
                                     0, 0, radius_in, width)
         self._default_size = _round_up_to_odd_integer(2 * radius_out)
-        super(Ring2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = 0
 
 
@@ -465,7 +473,7 @@ class Trapezoid1DKernel(Kernel1D):
     def __init__(self, width, slope=1., **kwargs):
         self._model = models.Trapezoid1D(1, 0, width, slope)
         self._default_size = _round_up_to_odd_integer(width + 2. / slope)
-        super(Trapezoid1DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = 0
         self.normalize()
 
@@ -525,7 +533,7 @@ class TrapezoidDisk2DKernel(Kernel2D):
     def __init__(self, radius, slope=1., **kwargs):
         self._model = models.TrapezoidDisk2D(1, 0, 0, radius, slope)
         self._default_size = _round_up_to_odd_integer(2 * radius + 2. / slope)
-        super(TrapezoidDisk2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = 0
         self.normalize()
 
@@ -535,7 +543,7 @@ class MexicanHat1DKernel(Kernel1D):
     1D Mexican hat filter kernel.
 
     The Mexican Hat, or inverted Gaussian-Laplace filter, is a
-    bandpass filter. It smooths the data and removes slowly varying
+    bandpass filter. It smoothes the data and removes slowly varying
     or constant structures (e.g. Background). It is useful for peak or
     multi-scale detection.
 
@@ -596,7 +604,7 @@ class MexicanHat1DKernel(Kernel1D):
         amplitude = 1.0 / (np.sqrt(2 * np.pi) * width ** 3)
         self._model = models.MexicanHat1D(amplitude, 0, width)
         self._default_size = _round_up_to_odd_integer(8 * width)
-        super(MexicanHat1DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = np.abs(self._array.sum() / self._array.size)
 
 
@@ -605,7 +613,7 @@ class MexicanHat2DKernel(Kernel2D):
     2D Mexican hat filter kernel.
 
     The Mexican Hat, or inverted Gaussian-Laplace filter, is a
-    bandpass filter. It smooths the data and removes slowly varying
+    bandpass filter. It smoothes the data and removes slowly varying
     or constant structures (e.g. Background). It is useful for peak or
     multi-scale detection.
 
@@ -669,7 +677,7 @@ class MexicanHat2DKernel(Kernel2D):
         amplitude = 1.0 / (np.pi * width ** 4)
         self._model = models.MexicanHat2D(amplitude, 0, 0, width)
         self._default_size = _round_up_to_odd_integer(8 * width)
-        super(MexicanHat2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._truncation = np.abs(self._array.sum() / self._array.size)
 
 
@@ -731,7 +739,7 @@ class AiryDisk2DKernel(Kernel2D):
     def __init__(self, radius, **kwargs):
         self._model = models.AiryDisk2D(1, 0, 0, radius)
         self._default_size = _round_up_to_odd_integer(8 * radius)
-        super(AiryDisk2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.normalize()
         self._truncation = None
 
@@ -793,12 +801,11 @@ class Moffat2DKernel(Kernel2D):
     _is_bool = False
 
     def __init__(self, gamma, alpha, **kwargs):
-        # Compute amplitude, from
-        # https://en.wikipedia.org/wiki/Moffat_distribution
-        amplitude = (alpha - 1.0) / (np.pi * gamma * gamma)
-        self._model = models.Moffat2D(amplitude, 0, 0, gamma, alpha)
-        self._default_size = _round_up_to_odd_integer(4.0 * self._model.fwhm)
-        super(Moffat2DKernel, self).__init__(**kwargs)
+        self._model = models.Moffat2D((gamma - 1.0) / (np.pi * alpha * alpha),
+                                      0, 0, gamma, alpha)
+        fwhm = 2.0 * alpha * (2.0 ** (1.0 / gamma) - 1.0) ** 0.5
+        self._default_size = _round_up_to_odd_integer(4.0 * fwhm)
+        super().__init__(**kwargs)
         self.normalize()
         self._truncation = None
 
@@ -864,7 +871,7 @@ class Model1DKernel(Kernel1D):
             self._model = model
         else:
             raise TypeError("Must be Fittable1DModel")
-        super(Model1DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class Model2DKernel(Kernel2D):
@@ -932,7 +939,7 @@ class Model2DKernel(Kernel2D):
             self._model = model
         else:
             raise TypeError("Must be Fittable2DModel")
-        super(Model2DKernel, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class PSFKernel(Kernel2D):
@@ -985,7 +992,7 @@ class CustomKernel(Kernel):
     """
     def __init__(self, array):
         self.array = array
-        super(CustomKernel, self).__init__(self._array)
+        super().__init__(self._array)
 
     @property
     def array(self):
