@@ -8,8 +8,6 @@ machines and we want the tests to pass there.
 TODO: check if these tests pass on 32-bit machines and implement
 higher-precision checks on 64-bit machines.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import pytest
 
@@ -20,7 +18,6 @@ from ... import EarthLocation
 from ... import Angle, SkyCoord
 
 
-@pytest.mark.remote_data
 def test_against_hor2eq():
     """Check that Astropy gives consistent results with an IDL hor2eq example.
 
@@ -94,7 +91,6 @@ def test_against_hor2eq():
     assert distance_noatm < 0.4 * u.arcsec
 
 
-@pytest.mark.remote_data
 def test_against_pyephem():
     """Check that Astropy gives consistent results with one PyEphem example.
 
@@ -131,7 +127,6 @@ def test_against_pyephem():
     assert distance < 1 * u.arcsec
 
 
-@pytest.mark.remote_data
 def test_against_jpl_horizons():
     """Check that Astropy gives consistent results with the JPL Horizons example.
 
@@ -154,8 +149,7 @@ def test_against_jpl_horizons():
     assert distance < 1 * u.arcsec
 
 
-@pytest.mark.remote_data
-@pytest.mark.xfail(reason="Current output is completely incorrect")
+@pytest.mark.xfail
 def test_fk5_equinox_and_epoch_j2000_0_to_topocentric_observed():
     """
     http://phn.github.io/pytpm/conversions.html#fk5-equinox-and-epoch-j2000-0-to-topocentric-observed
