@@ -5,7 +5,7 @@ import numpy as np
 
 from astropy import table
 
-asdf = pytest.importorskip('asdf')
+asdf = pytest.importorskip('asdf', minversion='2.0.0')
 from asdf.tests import helpers
 
 
