@@ -1,17 +1,15 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-
 import pytest
 import numpy as np
 from inspect import signature
-from numpy.testing.utils import assert_allclose
+from numpy.testing import assert_allclose
 
 from ..core import Model, custom_model
 from ..parameters import Parameter
 from .. import models
 
 
-
 class NonFittableModel(Model):
     """An example class directly subclassing Model for testing."""
 
