@@ -2,8 +2,7 @@
 import pytest
 import numpy as np
 
-from numpy.testing import assert_equal
-from numpy.testing.utils import assert_allclose
+from numpy.testing import assert_equal, assert_allclose
 
 from astropy import units as u
 
