@@ -4,8 +4,7 @@ import pytest
 
 import numpy as np
 from numpy.random import randn, normal
-from numpy.testing import assert_equal
-from numpy.testing.utils import assert_allclose
+from numpy.testing import assert_equal, assert_allclose
 
 try:
     import scipy  # pylint: disable=W0611
