@@ -10,8 +10,9 @@ from ...utils.data import get_pkg_data_contents, get_pkg_data_filename
 from ...time import Time
 from ... import units as u
 
-from ..wcs import WCS
-from ..utils import (proj_plane_pixel_scales, is_proj_plane_distorted,
+from ..wcs import WCS, Sip, WCSSUB_LONGITUDE, WCSSUB_LATITUDE
+from ..utils import (proj_plane_pixel_scales, proj_plane_pixel_area,
+                     is_proj_plane_distorted,
                      non_celestial_pixel_scales, wcs_to_celestial_frame,
                      celestial_frame_to_wcs, skycoord_to_pixel,
                      pixel_to_skycoord, custom_wcs_to_frame_mappings,
@@ -87,11 +88,18 @@ def test_slice():
     mywcs.wcs.cdelt = [0.1, 0.1]
     mywcs.wcs.crpix = [1, 1]
     mywcs._naxis = [1000, 500]
+    pscale = 0.1 # from cdelt
 
     slice_wcs = mywcs.slice([slice(1, None), slice(0, None)])
     assert np.all(slice_wcs.wcs.crpix == np.array([1, 0]))
     assert slice_wcs._naxis == [1000, 499]
 
+    # test that CRPIX maps to CRVAL:
+    assert_allclose(
+        slice_wcs.wcs_pix2world(*slice_wcs.wcs.crpix, 1),
+        slice_wcs.wcs.crval, rtol=0.0, atol=1e-6 * pscale
+    )
+
     slice_wcs = mywcs.slice([slice(1, None, 2), slice(0, None, 4)])
     assert np.all(slice_wcs.wcs.crpix == np.array([0.625, 0.25]))
     assert np.all(slice_wcs.wcs.cdelt == np.array([0.4, 0.2]))
@@ -110,6 +118,46 @@ def test_slice():
     assert slice_wcs._naxis == [1000, 50]
 
 
+def test_slice_with_sip():
+    mywcs = WCS(naxis=2)
+    mywcs.wcs.crval = [1, 1]
+    mywcs.wcs.cdelt = [0.1, 0.1]
+    mywcs.wcs.crpix = [1, 1]
+    mywcs._naxis = [1000, 500]
+    mywcs.wcs.ctype = ['RA---TAN-SIP', 'DEC--TAN-SIP']
+    a = np.array(
+        [[0, 0, 5.33092692e-08, 3.73753773e-11, -2.02111473e-13],
+         [0, 2.44084308e-05, 2.81394789e-11, 5.17856895e-13, 0.0],
+         [-2.41334657e-07, 1.29289255e-10, 2.35753629e-14, 0.0, 0.0],
+         [-2.37162007e-10, 5.43714947e-13, 0.0, 0.0, 0.0],
+         [ -2.81029767e-13, 0.0, 0.0, 0.0, 0.0]]
+    )
+    b = np.array(
+        [[0, 0, 2.99270374e-05, -2.38136074e-10, 7.23205168e-13],
+         [0, -1.71073858e-07, 6.31243431e-11, -5.16744347e-14, 0.0],
+         [6.95458963e-06, -3.08278961e-10, -1.75800917e-13, 0.0, 0.0],
+         [3.51974159e-11, 5.60993016e-14, 0.0, 0.0, 0.0],
+         [-5.92438525e-13, 0.0, 0.0, 0.0, 0.0]]
+    )
+    mywcs.sip = Sip(a, b, None, None, mywcs.wcs.crpix)
+    mywcs.wcs.set()
+    pscale = 0.1 # from cdelt
+
+    slice_wcs = mywcs.slice([slice(1, None), slice(0, None)])
+    # test that CRPIX maps to CRVAL:
+    assert_allclose(
+        slice_wcs.all_pix2world(*slice_wcs.wcs.crpix, 1),
+        slice_wcs.wcs.crval, rtol=0.0, atol=1e-6 * pscale
+    )
+
+    slice_wcs = mywcs.slice([slice(1, None, 2), slice(0, None, 4)])
+    # test that CRPIX maps to CRVAL:
+    assert_allclose(
+        slice_wcs.all_pix2world(*slice_wcs.wcs.crpix, 1),
+        slice_wcs.wcs.crval, rtol=0.0, atol=1e-6 * pscale
+    )
+
+
 def test_slice_getitem():
     mywcs = WCS(naxis=2)
     mywcs.wcs.crval = [1, 1]
@@ -190,58 +238,81 @@ def test_wcs_to_celestial_frame():
     from ...coordinates.builtin_frames import ICRS, FK5, FK4, Galactic
 
     mywcs = WCS(naxis=2)
+    mywcs.wcs.set()
     with pytest.raises(ValueError) as exc:
         assert wcs_to_celestial_frame(mywcs) is None
     assert exc.value.args[0] == "Could not determine celestial frame corresponding to the specified WCS object"
 
+    mywcs = WCS(naxis=2)
     mywcs.wcs.ctype = ['XOFFSET', 'YOFFSET']
+    mywcs.wcs.set()
     with pytest.raises(ValueError):
         assert wcs_to_celestial_frame(mywcs) is None
 
+    mywcs = WCS(naxis=2)
     mywcs.wcs.ctype = ['RA---TAN', 'DEC--TAN']
+    mywcs.wcs.set()
     frame = wcs_to_celestial_frame(mywcs)
     assert isinstance(frame, ICRS)
 
+    mywcs = WCS(naxis=2)
+    mywcs.wcs.ctype = ['RA---TAN', 'DEC--TAN']
     mywcs.wcs.equinox = 1987.
+    mywcs.wcs.set()
+    print(mywcs.to_header())
     frame = wcs_to_celestial_frame(mywcs)
     assert isinstance(frame, FK5)
     assert frame.equinox == Time(1987., format='jyear')
 
+    mywcs = WCS(naxis=2)
+    mywcs.wcs.ctype = ['RA---TAN', 'DEC--TAN']
     mywcs.wcs.equinox = 1982
+    mywcs.wcs.set()
     frame = wcs_to_celestial_frame(mywcs)
     assert isinstance(frame, FK4)
     assert frame.equinox == Time(1982., format='byear')
 
-    mywcs.wcs.equinox = np.nan
+    mywcs = WCS(naxis=2)
     mywcs.wcs.ctype = ['GLON-SIN', 'GLAT-SIN']
+    mywcs.wcs.set()
     frame = wcs_to_celestial_frame(mywcs)
     assert isinstance(frame, Galactic)
 
-    mywcs.wcs.ctype = ['RA---TAN', 'DEC--TAN']
-    mywcs.wcs.radesys = 'ICRS'
-
     for equinox in [np.nan, 1987, 1982]:
+        mywcs = WCS(naxis=2)
+        mywcs.wcs.ctype = ['RA---TAN', 'DEC--TAN']
+        mywcs.wcs.radesys = 'ICRS'
         mywcs.wcs.equinox = equinox
+        mywcs.wcs.set()
         frame = wcs_to_celestial_frame(mywcs)
         assert isinstance(frame, ICRS)
 
     # Flipped order
     mywcs = WCS(naxis=2)
     mywcs.wcs.ctype = ['DEC--TAN', 'RA---TAN']
+    mywcs.wcs.set()
     frame = wcs_to_celestial_frame(mywcs)
     assert isinstance(frame, ICRS)
 
     # More than two dimensions
     mywcs = WCS(naxis=3)
     mywcs.wcs.ctype = ['DEC--TAN', 'VELOCITY', 'RA---TAN']
+    mywcs.wcs.set()
     frame = wcs_to_celestial_frame(mywcs)
     assert isinstance(frame, ICRS)
 
+    mywcs = WCS(naxis=3)
+    mywcs.wcs.ctype = ['GLAT-CAR', 'VELOCITY', 'GLON-CAR']
+    mywcs.wcs.set()
+    frame = wcs_to_celestial_frame(mywcs)
+    assert isinstance(frame, Galactic)
+
 
 def test_wcs_to_celestial_frame_extend():
 
     mywcs = WCS(naxis=2)
     mywcs.wcs.ctype = ['XOFFSET', 'YOFFSET']
+    mywcs.wcs.set()
     with pytest.raises(ValueError):
         wcs_to_celestial_frame(mywcs)
 
@@ -486,6 +557,36 @@ def test_skycoord_to_pixel(mode):
     assert_allclose(new2.dec.degree, ref.dec.degree)
 
 
+def test_skycoord_to_pixel_swapped():
+
+    # Regression test for a bug that caused skycoord_to_pixel and
+    # pixel_to_skycoord to not work correctly if the axes were swapped in the
+    # WCS.
+
+    # Import astropy.coordinates here to avoid circular imports
+    from ...coordinates import SkyCoord
+
+    header = get_pkg_data_contents('maps/1904-66_TAN.hdr', encoding='binary')
+    wcs = WCS(header)
+
+    wcs_swapped = wcs.sub([WCSSUB_LATITUDE, WCSSUB_LONGITUDE])
+
+    ref = SkyCoord(0.1 * u.deg, -89. * u.deg, frame='icrs')
+
+    xp1, yp1 = skycoord_to_pixel(ref, wcs)
+    xp2, yp2 = skycoord_to_pixel(ref, wcs_swapped)
+
+    assert_allclose(xp1, xp2)
+    assert_allclose(yp1, yp2)
+
+    # WCS is in FK5 so we need to transform back to ICRS
+    new1 = pixel_to_skycoord(xp1, yp1, wcs).transform_to('icrs')
+    new2 = pixel_to_skycoord(xp1, yp1, wcs_swapped).transform_to('icrs')
+
+    assert_allclose(new1.ra.degree, new2.ra.degree)
+    assert_allclose(new1.dec.degree, new2.dec.degree)
+
+
 def test_is_proj_plane_distorted():
     # non-orthogonal CD:
     wcs = WCS(naxis=2)
